@@ -18,6 +18,7 @@ G_DEFINE_TYPE (EmpathyRosterView, empathy_roster_view, EGG_TYPE_LIST_BOX)
 enum
 {
   PROP_MANAGER = 1,
+  PROP_MODEL,
   PROP_SHOW_OFFLINE,
   PROP_SHOW_GROUPS,
   PROP_EMPTY,
@@ -66,6 +67,8 @@ struct _EmpathyRosterViewPriv
   gboolean empty;
 
   EmpathyLiveSearch *search;
+
+  EmpathyRosterModel *model;
 };
 
 typedef struct
@@ -114,6 +117,9 @@ empathy_roster_view_get_property (GObject *object,
       case PROP_MANAGER:
         g_value_set_object (value, self->priv->manager);
         break;
+      case PROP_MODEL:
+        g_value_set_object (value, self->priv->model);
+        break;
       case PROP_SHOW_OFFLINE:
         g_value_set_boolean (value, self->priv->show_offline);
         break;
@@ -143,6 +149,10 @@ empathy_roster_view_set_property (GObject *object,
         g_assert (self->priv->manager == NULL); /* construct only */
         self->priv->manager = g_value_dup_object (value);
         break;
+      case PROP_MODEL:
+        g_assert (self->priv->model == NULL);
+        self->priv->model = g_value_dup_object (value);
+        break;
       case PROP_SHOW_OFFLINE:
         empathy_roster_view_show_offline (self, g_value_get_boolean (value));
         break;
@@ -163,27 +173,6 @@ roster_contact_changed_cb (GtkWidget *child,
   egg_list_box_child_changed (EGG_LIST_BOX (self), child);
 }
 
-static gboolean
-is_xmpp_local_contact (FolksIndividual *individual)
-{
-  EmpathyContact *contact;
-  TpConnection *connection;
-  const gchar *protocol_name = NULL;
-  gboolean result;
-
-  contact = empathy_contact_dup_from_folks_individual (individual);
-
-  if (contact == NULL)
-    return FALSE;
-
-  connection = empathy_contact_get_connection (contact);
-  protocol_name = tp_connection_get_protocol_name (connection);
-  result = !tp_strdiff (protocol_name, "local-xmpp");
-  g_object_unref (contact);
-
-  return result;
-}
-
 static GtkWidget *
 add_roster_contact (EmpathyRosterView *self,
     FolksIndividual *individual,
@@ -322,13 +311,9 @@ individual_added (EmpathyRosterView *self,
     {
       add_to_group (self, individual, NO_GROUP);
     }
-  else if (is_xmpp_local_contact (individual))
-    {
-      add_to_group (self, individual, EMPATHY_ROSTER_VIEW_GROUP_PEOPLE_NEARBY);
-    }
   else
     {
-      GeeSet *groups;
+      GList *groups, *l;
       GList *tops;
 
       tops = empathy_individual_manager_get_top_individuals (
@@ -341,29 +326,23 @@ individual_added (EmpathyRosterView *self,
           add_to_group (self, individual, EMPATHY_ROSTER_VIEW_GROUP_TOP_GROUP);
         }
 
-      groups = folks_group_details_get_groups (
-          FOLKS_GROUP_DETAILS (individual));
+      groups = empathy_roster_model_get_groups_for_individual (self->priv->model,
+          individual);
 
-      if (gee_collection_get_size (GEE_COLLECTION (groups)) > 0)
+      if (g_list_length (groups) > 0)
         {
-          GeeIterator *iter = gee_iterable_iterator (GEE_ITERABLE (groups));
-
-          while (iter != NULL && gee_iterator_next (iter))
+          for (l = groups; l != NULL; l = g_list_next (l))
             {
-              gchar *group = gee_iterator_get (iter);
-
-              add_to_group (self, individual, group);
-
-              g_free (group);
+              add_to_group (self, individual, l->data);
             }
-
-          g_clear_object (&iter);
         }
       else
         {
           /* No group, adds to Ungrouped */
           add_to_group (self, individual, EMPATHY_ROSTER_VIEW_GROUP_UNGROUPED);
         }
+
+      g_list_free (groups);
     }
 }
 
@@ -511,28 +490,19 @@ individual_removed (EmpathyRosterView *self,
 }
 
 static void
-members_changed_cb (EmpathyIndividualManager *manager,
-    const gchar *message,
-    GList *added,
-    GList *removed,
-    TpChannelGroupChangeReason reason,
+individual_added_cb (EmpathyRosterModel *model,
+    FolksIndividual *individual,
     EmpathyRosterView *self)
 {
-  GList *l;
+  individual_added (self, individual);
+}
 
-  for (l = added; l != NULL; l = g_list_next (l))
-    {
-      FolksIndividual *individual = l->data;
-
-      individual_added (self, individual);
-    }
-
-  for (l = removed; l != NULL; l = g_list_next (l))
-    {
-      FolksIndividual *individual = l->data;
-
-      individual_removed (self, individual);
-    }
+static void
+individual_removed_cb (EmpathyRosterModel *model,
+    FolksIndividual *individual,
+    EmpathyRosterView *self)
+{
+  individual_removed (self, individual);
 }
 
 static gint
@@ -809,26 +779,30 @@ contact_should_be_displayed (EmpathyRosterView *self,
           empathy_live_search_get_text (self->priv->search),
           empathy_live_search_get_words (self->priv->search));
     }
-  else
+
+  if (self->priv->show_offline)
+      return TRUE;
+
+  if (contact_is_favourite (contact))
     {
-      if (self->priv->show_offline)
-        {
-          return TRUE;
-        }
-      else if (!self->priv->show_groups &&
-          contact_is_favourite (contact))
-        {
-          /* Always display favourite contacts in non-group mode. In the group
-           * mode we'll display only the one in the 'top' section. */
-          return TRUE;
-        }
-      else
-        {
-          return empathy_roster_contact_is_online (contact);
-        }
+      const gchar *group_name;
+
+      if (!self->priv->show_groups)
+        /* Always display favourite contacts in non-group mode. */
+        return TRUE;
+
+      group_name = empathy_roster_contact_get_group (contact);
+
+      if (!tp_strdiff (group_name, EMPATHY_ROSTER_VIEW_GROUP_TOP_GROUP))
+        /* Always display favourite contact in group mode only in the
+         * 'top group'*/
+        return TRUE;
     }
+
+  return empathy_roster_contact_is_online (contact);
 }
 
+
 static gboolean
 filter_contact (EmpathyRosterView *self,
     EmpathyRosterContact *contact)
@@ -845,10 +819,6 @@ filter_contact (EmpathyRosterView *self,
       group_name = empathy_roster_contact_get_group (contact);
       group = lookup_roster_group (self, group_name);
 
-      if (!tp_strdiff (group_name, EMPATHY_ROSTER_VIEW_GROUP_TOP_GROUP) &&
-          contact_is_favourite (contact))
-        displayed = TRUE;
-
       if (group != NULL)
         {
           /* When searching, always display even if the group is closed */
@@ -930,7 +900,7 @@ populate_view (EmpathyRosterView *self)
 {
   GList *individuals, *l;
 
-  individuals = empathy_individual_manager_get_members (self->priv->manager);
+  individuals = empathy_roster_model_get_individuals (self->priv->model);
   for (l = individuals; l != NULL; l = g_list_next (l))
     {
       FolksIndividual *individual = l->data;
@@ -1039,9 +1009,9 @@ update_top_contacts (EmpathyRosterView *self)
 }
 
 static void
-groups_changed_cb (EmpathyIndividualManager *manager,
+groups_changed_cb (EmpathyRosterModel *model,
     FolksIndividual *individual,
-    gchar *group,
+    const gchar *group,
     gboolean is_member,
     EmpathyRosterView *self)
 {
@@ -1109,12 +1079,15 @@ empathy_roster_view_constructed (GObject *object)
     chain_up (object);
 
   g_assert (EMPATHY_IS_INDIVIDUAL_MANAGER (self->priv->manager));
+  g_assert (EMPATHY_IS_ROSTER_MODEL (self->priv->model));
 
   populate_view (self);
 
-  tp_g_signal_connect_object (self->priv->manager, "members-changed",
-      G_CALLBACK (members_changed_cb), self, 0);
-  tp_g_signal_connect_object (self->priv->manager, "groups-changed",
+  tp_g_signal_connect_object (self->priv->model, "individual-added",
+      G_CALLBACK (individual_added_cb), self, 0);
+  tp_g_signal_connect_object (self->priv->model, "individual-removed",
+      G_CALLBACK (individual_removed_cb), self, 0);
+  tp_g_signal_connect_object (self->priv->model, "groups-changed",
       G_CALLBACK (groups_changed_cb), self, 0);
   tp_g_signal_connect_object (self->priv->manager, "notify::top-individuals",
       G_CALLBACK (top_individuals_changed_cb), self, 0);
@@ -1143,6 +1116,7 @@ empathy_roster_view_dispose (GObject *object)
 
   empathy_roster_view_set_live_search (self, NULL);
   g_clear_object (&self->priv->manager);
+  g_clear_object (&self->priv->model);
 
   if (chain_up != NULL)
     chain_up (object);
@@ -1375,6 +1349,12 @@ empathy_roster_view_class_init (
       G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY | G_PARAM_STATIC_STRINGS);
   g_object_class_install_property (oclass, PROP_MANAGER, spec);
 
+  spec = g_param_spec_object ("model", "Model",
+      "EmpathyRosterModel",
+      EMPATHY_TYPE_ROSTER_MODEL,
+      G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY | G_PARAM_STATIC_STRINGS);
+  g_object_class_install_property (oclass, PROP_MODEL, spec);
+
   spec = g_param_spec_boolean ("show-offline", "Show Offline",
       "Show offline contacts",
       FALSE,
@@ -1442,12 +1422,15 @@ empathy_roster_view_init (EmpathyRosterView *self)
 }
 
 GtkWidget *
-empathy_roster_view_new (EmpathyIndividualManager *manager)
+empathy_roster_view_new (EmpathyIndividualManager *manager,
+    EmpathyRosterModel *model)
 {
   g_return_val_if_fail (EMPATHY_IS_INDIVIDUAL_MANAGER (manager), NULL);
+  g_return_val_if_fail (EMPATHY_IS_ROSTER_MODEL (model), NULL);
 
   return g_object_new (EMPATHY_TYPE_ROSTER_VIEW,
       "manager", manager,
+      "model", model,
       NULL);
 }
 
