@@ -326,7 +326,7 @@ account_can_be_enabled (TpAccount *account)
     return FALSE;
 
   /* Butterfly accounts shouldn't be used any more */
-  if (!tp_strdiff (tp_account_get_connection_manager (account),
+  if (!tp_strdiff (tp_account_get_cm_name (account),
         "butterfly"))
     return FALSE;
 
@@ -482,7 +482,7 @@ accounts_dialog_update_status_infobar (EmpathyAccountsDialog *dialog,
     }
   else
     {
-      if (!tp_strdiff (tp_account_get_connection_manager (account),
+      if (!tp_strdiff (tp_account_get_cm_name (account),
             "butterfly"))
         {
           const gchar *packages[] = { "telepathy-haze", NULL };
@@ -790,18 +790,25 @@ create_contact_info_editor (EmpathyAccountsDialog *self,
   EmpathyAccountsDialogPriv *priv = GET_PRIV (self);
   GtkWidget *editor, *alig;
   EmpathyContact *contact;
+  EmpathyContactWidgetFlags flags;
+  TpConnection *conn;
 
   contact = empathy_contact_dup_from_tp_contact (tp_contact);
 
   alig = gtk_alignment_new (0.5, 0, 1, 1);
 
-  /* create the contact info editor for this account */
-  editor = empathy_contact_widget_new (contact,
-      EMPATHY_CONTACT_WIDGET_EDIT_ALIAS |
-      EMPATHY_CONTACT_WIDGET_EDIT_AVATAR |
+  flags = EMPATHY_CONTACT_WIDGET_EDIT_ALIAS |
       EMPATHY_CONTACT_WIDGET_NO_STATUS |
       EMPATHY_CONTACT_WIDGET_EDIT_DETAILS |
-      EMPATHY_CONTACT_WIDGET_NO_ACCOUNT);
+      EMPATHY_CONTACT_WIDGET_NO_ACCOUNT;
+
+  conn = tp_contact_get_connection (tp_contact);
+  if (tp_proxy_has_interface_by_id (conn,
+        TP_IFACE_QUARK_CONNECTION_INTERFACE_AVATARS))
+    flags |= EMPATHY_CONTACT_WIDGET_EDIT_AVATAR;
+
+  /* create the contact info editor for this account */
+  editor = empathy_contact_widget_new (contact, flags);
 
   gtk_box_pack_start (GTK_BOX (priv->dialog_content), alig, TRUE, TRUE, 0);
   gtk_container_add (GTK_CONTAINER (alig), editor);
